==> mktcenter-service-2.0.2-20201027.100441-84-sources.jar: com/bizvane/mktcenterservice/interfaces/ConvertCouponService.java <==
package com.bizvane.mktcenterservice.interfaces;

import com.bizvane.mktcenterservice.models.bo.CouponIntegralExchangeBO;
import com.bizvane.mktcenterservice.models.po.MktConvertCouponRecordPO;
import com.bizvane.mktcenterservice.models.po.MktConvertCouponRecordPOWithBLOBs;
import com.bizvane.mktcenterservice.models.vo.CouponIntegralExchangeVO;
import com.bizvane.mktcenterservice.models.vo.CouponRecordVO;
import com.bizvane.utils.responseinfo.ResponseData;
import com.github.pagehelper.PageInfo;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * @Author: lijunwei
 * @Time: 2018/11/23 11:28
 */
public interface ConvertCouponService {

    public ResponseData<PageInfo<MktConvertCouponRecordPO>> getCouponRecordLists(CouponRecordVO vo);

    public ResponseData<CouponIntegralExchangeBO> getConvernCouponLists(CouponRecordVO vo);

    public ResponseData<String> doConvernCoupon(CouponRecordVO vo);

    public ResponseData<PageInfo<MktConvertCouponRecordPO>> getConvernConpouByMember(CouponRecordVO vo);

    public void doExportData(CouponRecordVO vo,HttpServletResponse response) throws IOException;

    public ResponseData doExportData001(CouponRecordVO vo, HttpServletRequest request);

    public ResponseData<CouponIntegralExchangeVO> getCouponAndPrice(CouponRecordVO vo);

    public ResponseData<MktConvertCouponRecordPOWithBLOBs> getConvernConpouDetail(Long convertCouponRecordId);

    public ResponseData validateConvernCoupon(CouponRecordVO vo);

    public ResponseData<MktConvertCouponRecordPO> paySuccess(Long convertCouponRecordId);
}

==> mktcenter-service-2.1.2-20220411.093045-8-sources.jar: com/bizvane/mktcenterservice/interfaces/ConvertCouponService.java <==
package com.bizvane.mktcenterservice.interfaces;

import com.bizvane.centerstageservice.models.vo.SysAccountVo;
import com.bizvane.mktcenterservice.models.bo.CouponIntegralExchangeBO;
import com.bizvane.mktcenterservice.models.po.MktConvertCouponRecordPO;
import com.bizvane.mktcenterservice.models.po.MktConvertCouponRecordPOWithBLOBs;
import com.bizvane.mktcenterservice.models.po.MktCouponIntegralExchangePO;
import com.bizvane.mktcenterservice.models.vo.CouponIntegralExchangeVO;
import com.bizvane.mktcenterservice.models.vo.CouponRecordVO;
import com.bizvane.mktcenterservice.models.vo.MktConvertCouponRecordVO;
import com.bizvane.mktcenterservice.models.vo.MktGiftBagVO;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;
import com.github.pagehelper.PageInfo;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;
import java.util.Objects;

/**
 * @Author: lijunwei
 * @Time: 2018/11/23 11:28
 */
public interface ConvertCouponService {

    public ResponseData<PageInfo<MktConvertCouponRecordVO>> getCouponRecordLists(CouponRecordVO vo, SysAccountPO sysAccountPo);

    public ResponseData<CouponIntegralExchangeBO> getConvernCouponLists(CouponRecordVO vo);

    public ResponseData<String> doConvernCoupon(CouponRecordVO vo);

    public ResponseData<PageInfo<MktConvertCouponRecordPO>> getConvernConpouByMember(CouponRecordVO vo);

    public void doExportData(CouponRecordVO vo,HttpServletResponse response) throws IOException;

    public ResponseData doExportData001(CouponRecordVO vo, HttpServletRequest request);

    public ResponseData<CouponIntegralExchangeVO> getCouponAndPrice(CouponRecordVO vo);

    public ResponseData<MktConvertCouponRecordPOWithBLOBs> getConvernConpouDetail(Long convertCouponRecordId);

    public ResponseData validateConvernCoupon(CouponRecordVO vo);

    public ResponseData<MktConvertCouponRecordPO> paySuccess(Long convertCouponRecordId);

    ResponseData<MktGiftBagVO> getGiftBag(Long bizId);

    Boolean getMemberDataDesensitizeByAccountConfig(Long sysAccountId);

    /**
     * 通过兑换编号获取兑换券详情(单个)exchangeCode必传 (批量)exchangeCodes必传
     * @param vo
     * @return
     */
    ResponseData<List<MktCouponIntegralExchangePO>> getCouponIntegralExchangeByCode(CouponRecordVO vo);

}
